Ranged

Trait Ranged 

pub trait Ranged {
    // Required method
    fn range(&self) -> TextRange;

    // Provided methods
    fn start(&self) -> TextSize { ... }
    fn end(&self) -> TextSize { ... }
}
A ranged item in the source text.

Required Methods

fn range(&self) -> TextRange

The range of this item in the source text.

Provided Methods

fn start(&self) -> TextSize

The start offset of this item in the source text.

fn end(&self) -> TextSize

The end offset of this item in the source text.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> Ranged for &T
where T: Ranged,

Source

impl<T> Ranged for Arc<T>
where T: Ranged,

Implementors