pub trait Ranged { // Required method fn range(&self) -> TextRange; // Provided methods fn start(&self) -> TextSize { ... } fn end(&self) -> TextSize { ... } }
A ranged item in the source text.
The range of this item in the source text.
The start offset of this item in the source text.
The end offset of this item in the source text.